@@ -23,8 +23,7 @@
 #include "comboboxdelegate.h"
 #include <QHeaderView>
 
-MethodTableView::MethodTableView(QWidget* parent)
-  : QTableView(parent)
+MethodTableView::MethodTableView(QWidget *parent) : QTableView(parent)
 {
   QStringList accessTypes;
   accessTypes << "public"
@@ -40,25 +39,25 @@ MethodTableView::MethodTableView(QWidget* parent)
 
   QStringList types;
   types << "void";
-  for ( int i = 0; i < sizeof sTypes / sizeof *sTypes; ++i)
+  for (int i = 0; i < sizeof sTypes / sizeof *sTypes; ++i)
     types << *(sTypes + i);
 
-  setItemDelegateForColumn(2, new ComboBoxDelegate(types, ComboBoxDelegate::Editable));
+  setItemDelegateForColumn(
+      2, new ComboBoxDelegate(types, ComboBoxDelegate::Editable));
 
   setEditTriggers(QAbstractItemView::AllEditTriggers);
   horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
 }
 
-ArgsTableView::ArgsTableView(QWidget* parent)
-  : QTableView(parent)
+ArgsTableView::ArgsTableView(QWidget *parent) : QTableView(parent)
 {
   QStringList types;
-  for ( int i = 0; i < sizeof sTypes / sizeof *sTypes; ++i)
+  for (int i = 0; i < sizeof sTypes / sizeof *sTypes; ++i)
     types << *(sTypes + i);
 
-  setItemDelegateForColumn(0, new ComboBoxDelegate(types, ComboBoxDelegate::Editable));
+  setItemDelegateForColumn(
+      0, new ComboBoxDelegate(types, ComboBoxDelegate::Editable));
 
   setEditTriggers(QAbstractItemView::AllEditTriggers);
   horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
-
 }
