@@ -18,28 +18,24 @@
 
 */
 
-
 #ifndef AUDIOOBJECT_H
 #define AUDIOOBJECT_H
 
-#include <QtCore/QObject>
 #include <QTextObjectInterface>
+#include <QtCore/QObject>
 
-enum CustomType
-{
+enum CustomType {
   AudioType = QTextFormat::UserObject,
 
   NumTypes
 };
 
-enum CustomProperty
-{
+enum CustomProperty {
   AudioProperty = QTextFormat::UserProperty,
 
   NumProperties
 };
 
-
 /**
   @brief A text object representing an audio snippet
 */
@@ -48,17 +44,19 @@ class AudioObject : public QObject, public QTextObjectInterface
   Q_OBJECT
   Q_INTERFACES(QTextObjectInterface)
 public:
-  AudioObject( QObject *parent = 0 );
+  AudioObject(QObject *parent = 0);
 
-  virtual void drawObject(QPainter* painter, const QRectF& rect, QTextDocument* doc, int posInDocument, const QTextFormat& format);
-  virtual QSizeF intrinsicSize(QTextDocument* doc, int posInDocument, const QTextFormat& format);
+  virtual void drawObject(QPainter *painter, const QRectF &rect,
+                          QTextDocument *doc, int posInDocument,
+                          const QTextFormat &format);
+  virtual QSizeF intrinsicSize(QTextDocument *doc, int posInDocument,
+                               const QTextFormat &format);
 };
 
 class AudioFormat : public QTextCharFormat
 {
 public:
   AudioFormat();
-
 };
 
 #endif // AUDIOOBJECT_H
