@@ -46,18 +46,12 @@
 #include <QClipboard>
 #include <QCloseEvent>
 #include <QColorDialog>
-#include <QComboBox>
 #include <QFile>
 #include <QFileDialog>
 #include <QFileInfo>
-#include <QFontComboBox>
-#include <QFontDatabase>
 #include <QMenu>
 #include <QMenuBar>
 #include <QMessageBox>
-#include <QPrintDialog>
-#include <QPrintPreviewDialog>
-#include <QPrinter>
 #include <QSplitter>
 #include <QTextCodec>
 #include <QTextCursor>
@@ -65,7 +59,6 @@
 #include <QTextEdit>
 #include <QTextList>
 #include <QToolBar>
-#include <QWebView>
 #include <QtDebug>
 
 #include "grantlee_paths.h"
@@ -73,7 +66,6 @@
 #include <grantlee/engine.h>
 
 #include "audioobject.h"
-#include "audiotextedit.h"
 
 #ifdef Q_WS_MAC
 const QString rsrcPath = ":/images/mac";
@@ -97,7 +89,9 @@ TextEdit::TextEdit(QWidget *parent) : QMainWindow(parent)
 
   abstractTextEdit = new QTextEdit(this);
 
-  textEdit = new AudioTextEdit(this);
+  abstractTextEdit->append("This is the abstract");
+
+  textEdit = new QTextEdit(this);
   connect(textEdit, SIGNAL(currentCharFormatChanged(QTextCharFormat)), this,
           SLOT(currentCharFormatChanged(QTextCharFormat)));
   connect(textEdit, SIGNAL(cursorPositionChanged()), this,
@@ -113,14 +107,13 @@ TextEdit::TextEdit(QWidget *parent) : QMainWindow(parent)
   splitter->addWidget(abstractTextEdit);
   splitter->addWidget(textEdit);
 
-  webView = new QWebView(this);
+  webView = new QTextEdit(this);
   hSplitter->addWidget(webView);
 
   setCentralWidget(hSplitter);
   textEdit->setFocus();
   setCurrentFileName(QString());
 
-  fontChanged(textEdit->font());
   colorChanged(textEdit->textColor());
   alignmentChanged(textEdit->alignment());
 
@@ -192,7 +185,6 @@ void TextEdit::setupFileActions()
   a->setPriority(QAction::LowPriority);
   a->setShortcut(QKeySequence::New);
   connect(a, SIGNAL(triggered()), this, SLOT(fileNew()));
-  tb->addAction(a);
   menu->addAction(a);
 
   a = new QAction(
@@ -200,7 +192,6 @@ void TextEdit::setupFileActions()
       tr("&Open..."), this);
   a->setShortcut(QKeySequence::Open);
   connect(a, SIGNAL(triggered()), this, SLOT(fileOpen()));
-  tb->addAction(a);
   menu->addAction(a);
 
   menu->addSeparator();
@@ -211,7 +202,6 @@ void TextEdit::setupFileActions()
   a->setShortcut(QKeySequence::Save);
   connect(a, SIGNAL(triggered()), this, SLOT(fileSave()));
   a->setEnabled(false);
-  tb->addAction(a);
   menu->addAction(a);
 
   a = new QAction(tr("Save &As..."), this);
@@ -220,34 +210,6 @@ void TextEdit::setupFileActions()
   menu->addAction(a);
   menu->addSeparator();
 
-#ifndef QT_NO_PRINTER
-  a = new QAction(
-      QIcon::fromTheme("document-print", QIcon(rsrcPath + "/fileprint.png")),
-      tr("&Print..."), this);
-  a->setPriority(QAction::LowPriority);
-  a->setShortcut(QKeySequence::Print);
-  connect(a, SIGNAL(triggered()), this, SLOT(filePrint()));
-  tb->addAction(a);
-  menu->addAction(a);
-
-  a = new QAction(
-      QIcon::fromTheme("fileprint", QIcon(rsrcPath + "/fileprint.png")),
-      tr("Print Preview..."), this);
-  connect(a, SIGNAL(triggered()), this, SLOT(filePrintPreview()));
-  menu->addAction(a);
-
-  a = new QAction(
-      QIcon::fromTheme("exportpdf", QIcon(rsrcPath + "/exportpdf.png")),
-      tr("&Export PDF..."), this);
-  a->setPriority(QAction::LowPriority);
-  a->setShortcut(Qt::CTRL + Qt::Key_D);
-  connect(a, SIGNAL(triggered()), this, SLOT(filePrintPdf()));
-  tb->addAction(a);
-  menu->addAction(a);
-
-  menu->addSeparator();
-#endif
-
   a = new QAction(QIcon::fromTheme("export_themed_html"),
                   tr("&Export Themed HTML"), this);
   a->setPriority(QAction::LowPriority);
@@ -280,9 +242,6 @@ void TextEdit::setupFileActions()
 
 void TextEdit::setupEditActions()
 {
-  QToolBar *tb = new QToolBar(this);
-  tb->setWindowTitle(tr("Edit Actions"));
-  addToolBar(tb);
   QMenu *menu = new QMenu(tr("&Edit"), this);
   menuBar()->addMenu(menu);
 
@@ -291,14 +250,12 @@ void TextEdit::setupEditActions()
       QIcon::fromTheme("edit-undo", QIcon(rsrcPath + "/editundo.png")),
       tr("&Undo"), this);
   a->setShortcut(QKeySequence::Undo);
-  tb->addAction(a);
   menu->addAction(a);
   a = actionRedo = new QAction(
       QIcon::fromTheme("edit-redo", QIcon(rsrcPath + "/editredo.png")),
       tr("&Redo"), this);
   a->setPriority(QAction::LowPriority);
   a->setShortcut(QKeySequence::Redo);
-  tb->addAction(a);
   menu->addAction(a);
   menu->addSeparator();
   a = actionCut = new QAction(
@@ -306,21 +263,18 @@ void TextEdit::setupEditActions()
       tr("Cu&t"), this);
   a->setPriority(QAction::LowPriority);
   a->setShortcut(QKeySequence::Cut);
-  tb->addAction(a);
   menu->addAction(a);
   a = actionCopy = new QAction(
       QIcon::fromTheme("edit-copy", QIcon(rsrcPath + "/editcopy.png")),
       tr("&Copy"), this);
   a->setPriority(QAction::LowPriority);
   a->setShortcut(QKeySequence::Copy);
-  tb->addAction(a);
   menu->addAction(a);
   a = actionPaste = new QAction(
       QIcon::fromTheme("edit-paste", QIcon(rsrcPath + "/editpaste.png")),
       tr("&Paste"), this);
   a->setPriority(QAction::LowPriority);
   a->setShortcut(QKeySequence::Paste);
-  tb->addAction(a);
   menu->addAction(a);
 #ifndef QT_NO_CLIPBOARD
   actionPaste->setEnabled(!QApplication::clipboard()->text().isEmpty());
@@ -329,10 +283,6 @@ void TextEdit::setupEditActions()
 
 void TextEdit::setupTextActions()
 {
-  QToolBar *tb = new QToolBar(this);
-  tb->setWindowTitle(tr("Format Actions"));
-  addToolBar(tb);
-
   QMenu *menu = new QMenu(tr("F&ormat"), this);
   menuBar()->addMenu(menu);
 
@@ -345,7 +295,6 @@ void TextEdit::setupTextActions()
   bold.setBold(true);
   actionTextBold->setFont(bold);
   connect(actionTextBold, SIGNAL(triggered()), this, SLOT(textBold()));
-  tb->addAction(actionTextBold);
   menu->addAction(actionTextBold);
   actionTextBold->setCheckable(true);
 
@@ -359,7 +308,6 @@ void TextEdit::setupTextActions()
   italic.setItalic(true);
   actionTextItalic->setFont(italic);
   connect(actionTextItalic, SIGNAL(triggered()), this, SLOT(textItalic()));
-  tb->addAction(actionTextItalic);
   menu->addAction(actionTextItalic);
   actionTextItalic->setCheckable(true);
 
@@ -374,7 +322,6 @@ void TextEdit::setupTextActions()
   actionTextUnderline->setFont(underline);
   connect(actionTextUnderline, SIGNAL(triggered()), this,
           SLOT(textUnderline()));
-  tb->addAction(actionTextUnderline);
   menu->addAction(actionTextUnderline);
   actionTextUnderline->setCheckable(true);
 
@@ -429,7 +376,6 @@ void TextEdit::setupTextActions()
   actionAlignJustify->setCheckable(true);
   actionAlignJustify->setPriority(QAction::LowPriority);
 
-  tb->addActions(grp->actions());
   menu->addActions(grp->actions());
 
   menu->addSeparator();
@@ -438,45 +384,7 @@ void TextEdit::setupTextActions()
   pix.fill(Qt::black);
   actionTextColor = new QAction(pix, tr("&Color..."), this);
   connect(actionTextColor, SIGNAL(triggered()), this, SLOT(textColor()));
-  tb->addAction(actionTextColor);
   menu->addAction(actionTextColor);
-
-  tb = new QToolBar(this);
-  tb->setAllowedAreas(Qt::TopToolBarArea | Qt::BottomToolBarArea);
-  tb->setWindowTitle(tr("Format Actions"));
-  addToolBarBreak(Qt::TopToolBarArea);
-  addToolBar(tb);
-
-  comboStyle = new QComboBox(tb);
-  tb->addWidget(comboStyle);
-  comboStyle->addItem("Standard");
-  comboStyle->addItem("Bullet List (Disc)");
-  comboStyle->addItem("Bullet List (Circle)");
-  comboStyle->addItem("Bullet List (Square)");
-  comboStyle->addItem("Ordered List (Decimal)");
-  comboStyle->addItem("Ordered List (Alpha lower)");
-  comboStyle->addItem("Ordered List (Alpha upper)");
-  comboStyle->addItem("Ordered List (Roman lower)");
-  comboStyle->addItem("Ordered List (Roman upper)");
-  connect(comboStyle, SIGNAL(activated(int)), this, SLOT(textStyle(int)));
-
-  comboFont = new QFontComboBox(tb);
-  tb->addWidget(comboFont);
-  connect(comboFont, SIGNAL(activated(QString)), this,
-          SLOT(textFamily(QString)));
-
-  comboSize = new QComboBox(tb);
-  comboSize->setObjectName("comboSize");
-  tb->addWidget(comboSize);
-  comboSize->setEditable(true);
-
-  QFontDatabase db;
-  Q_FOREACH (int size, db.standardSizes())
-    comboSize->addItem(QString::number(size));
-
-  connect(comboSize, SIGNAL(activated(QString)), this, SLOT(textSize(QString)));
-  comboSize->setCurrentIndex(
-      comboSize->findText(QString::number(QApplication::font().pointSize())));
 }
 
 bool TextEdit::load(const QString &f)
@@ -497,6 +405,12 @@ bool TextEdit::load(const QString &f)
     textEdit->setPlainText(str);
   }
 
+  auto tc = textEdit->document()->find("[audio]");
+  textEdit->setTextCursor(tc);
+  addAudio();
+  tc.movePosition(QTextCursor::Start);
+  textEdit->setTextCursor(tc);
+
   setCurrentFileName(f);
   return true;
 }
@@ -578,59 +492,6 @@ bool TextEdit::fileSaveAs()
   return fileSave();
 }
 
-void TextEdit::filePrint()
-{
-#ifndef QT_NO_PRINTER
-  QPrinter printer(QPrinter::HighResolution);
-  QPrintDialog *dlg = new QPrintDialog(&printer, this);
-  if (textEdit->textCursor().hasSelection())
-    dlg->addEnabledOption(QAbstractPrintDialog::PrintSelection);
-  dlg->setWindowTitle(tr("Print Document"));
-  if (dlg->exec() == QDialog::Accepted) {
-    textEdit->print(&printer);
-  }
-  delete dlg;
-#endif
-}
-
-void TextEdit::filePrintPreview()
-{
-#ifndef QT_NO_PRINTER
-  QPrinter printer(QPrinter::HighResolution);
-  QPrintPreviewDialog preview(&printer, this);
-  connect(&preview, SIGNAL(paintRequested(QPrinter *)),
-          SLOT(printPreview(QPrinter *)));
-  preview.exec();
-#endif
-}
-
-void TextEdit::printPreview(QPrinter *printer)
-{
-#ifdef QT_NO_PRINTER
-  Q_UNUSED(printer);
-#else
-  textEdit->print(printer);
-#endif
-}
-
-void TextEdit::filePrintPdf()
-{
-#ifndef QT_NO_PRINTER
-  //! [0]
-  QString fileName
-      = QFileDialog::getSaveFileName(this, "Export PDF", QString(), "*.pdf");
-  if (!fileName.isEmpty()) {
-    if (QFileInfo(fileName).suffix().isEmpty())
-      fileName.append(".pdf");
-    QPrinter printer(QPrinter::HighResolution);
-    printer.setOutputFormat(QPrinter::PdfFormat);
-    printer.setOutputFileName(fileName);
-    textEdit->document()->print(&printer);
-  }
-//! [0]
-#endif
-}
-
 void TextEdit::exportThemedHtml()
 {
   Grantlee::Engine *engine = new Grantlee::Engine();
@@ -656,7 +517,7 @@ void TextEdit::exportThemedHtml()
 
   QString result = t->render(&c);
 
-  webView->setHtml(result);
+  webView->setPlainText(result);
 }
 
 void TextEdit::exportPlainText()
@@ -682,7 +543,7 @@ void TextEdit::exportPlainText()
 
   QString result = t->render(&c);
 
-  webView->setContent(result.toUtf8(), "text/plain");
+  webView->setPlainText(result);
 }
 
 void TextEdit::textBold()
@@ -810,7 +671,6 @@ void TextEdit::textAlign(QAction *a)
 
 void TextEdit::currentCharFormatChanged(const QTextCharFormat &format)
 {
-  fontChanged(format.font());
   colorChanged(format.foreground().color());
 }
 
@@ -844,16 +704,6 @@ void TextEdit::mergeFormatOnWordOrSelection(const QTextCharFormat &format)
   textEdit->mergeCurrentCharFormat(format);
 }
 
-void TextEdit::fontChanged(const QFont &f)
-{
-  comboFont->setCurrentIndex(comboFont->findText(QFontInfo(f).family()));
-  comboSize->setCurrentIndex(
-      comboSize->findText(QString::number(f.pointSize())));
-  actionTextBold->setChecked(f.bold());
-  actionTextItalic->setChecked(f.italic());
-  actionTextUnderline->setChecked(f.underline());
-}
-
 void TextEdit::colorChanged(const QColor &c)
 {
   QPixmap pix(16, 16);
