@@ -30,17 +30,15 @@ using namespace Grantlee;
 class AddFilter : public Filter
 {
 public:
-  QVariant doFilter(const QVariant &input,
-                    const QVariant &argument = QVariant(),
-                    bool autoescape = false) const override;
+  QVariant doFilter(const QVariant &input, const QVariant &argument = {},
+                    bool autoescape = {}) const override;
 };
 
 class GetDigitFilter : public Filter
 {
 public:
-  QVariant doFilter(const QVariant &input,
-                    const QVariant &argument = QVariant(),
-                    bool autoescape = false) const override;
+  QVariant doFilter(const QVariant &input, const QVariant &argument = {},
+                    bool autoescape = {}) const override;
 };
 
 #endif
