@@ -22,29 +22,21 @@
 
 #include "parser.h"
 
+CommentNodeFactory::CommentNodeFactory() = default;
 
-CommentNodeFactory::CommentNodeFactory()
+Node *CommentNodeFactory::getNode(const QString &tagContent, Parser *p) const
 {
+  Q_UNUSED(tagContent);
 
+  p->skipPast(QStringLiteral("endcomment"));
+
+  return new CommentNode(p);
 }
 
-Node* CommentNodeFactory::getNode( const QString &tagContent, Parser *p ) const
+CommentNode::CommentNode(QObject *parent) : Node(parent) {}
+
+void CommentNode::render(OutputStream *stream, Context *c) const
 {
-  Q_UNUSED( tagContent );
-
-  p->skipPast( QStringLiteral( "endcomment" ) );
-
-  return new CommentNode( p );
-}
-
-CommentNode::CommentNode( QObject *parent )
-    : Node( parent )
-{
-
-}
-
-void CommentNode::render( OutputStream *stream, Context *c ) const
-{
-  Q_UNUSED( stream );
-  Q_UNUSED( c );
+  Q_UNUSED(stream);
+  Q_UNUSED(c);
 }
