@@ -23,11 +23,17 @@
 #include "../lib/exception.h"
 #include "parser.h"
 
-LoadNodeFactory::LoadNodeFactory() {}
+LoadNodeFactory::LoadNodeFactory() = default;
 
 Node *LoadNodeFactory::getNode(const QString &tagContent, Parser *p) const
 {
-  auto expr = tagContent.split(QLatin1Char(' '), QString::SkipEmptyParts);
+  auto expr = tagContent.split(QLatin1Char(' '),
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+                               QString::SkipEmptyParts
+#else
+                               Qt::SkipEmptyParts
+#endif
+  );
 
   if (expr.size() <= 1) {
     throw Grantlee::Exception(
