@@ -25,26 +25,25 @@
 
 using namespace Grantlee;
 
-class MediaFinderNodeFactory: public AbstractNodeFactory
+class MediaFinderNodeFactory : public AbstractNodeFactory
 {
 public:
   MediaFinderNodeFactory();
 
-  Node* getNode( const QString &tagContent, Parser *p ) const;
-
+  Node *getNode(const QString &tagContent, Parser *p) const override;
 };
 
 class MediaFinderNode : public Node
 {
   Q_OBJECT
 public:
-  explicit MediaFinderNode( QList<FilterExpression> mediaExpressionList, QObject *parent = 0 );
+  explicit MediaFinderNode(const QList<FilterExpression> &mediaExpressionList,
+                           QObject *parent = {});
 
-  void render( OutputStream *stream, Context *c ) const;
+  void render(OutputStream *stream, Context *c) const override;
 
 private:
   QList<FilterExpression> m_mediaExpressionList;
 };
 
-
 #endif
