@@ -20,50 +20,41 @@
 
 #include "spaceless.h"
 
+#include <QtCore/QRegularExpression>
+
 #include "parser.h"
 #include "util.h"
 
-SpacelessNodeFactory::SpacelessNodeFactory()
-{
+SpacelessNodeFactory::SpacelessNodeFactory() = default;
 
-}
-
-Node* SpacelessNodeFactory::getNode( const QString &tagContent, Parser *p ) const
+Node *SpacelessNodeFactory::getNode(const QString &tagContent, Parser *p) const
 {
-  Q_UNUSED( tagContent )
-  SpacelessNode *n = new SpacelessNode( p );
-  NodeList list = p->parse( n, QStringLiteral( "endspaceless" ) );
-  n->setList( list );
+  Q_UNUSED(tagContent)
+  auto n = new SpacelessNode(p);
+  auto list = p->parse(n, QStringLiteral("endspaceless"));
+  n->setList(list);
   p->removeNextToken();
   return n;
 }
 
-SpacelessNode::SpacelessNode( QObject *parent )
-    : Node( parent )
+SpacelessNode::SpacelessNode(QObject *parent) : Node(parent) {}
+
+void SpacelessNode::setList(const NodeList &nodeList) { m_nodeList = nodeList; }
+
+QString SpacelessNode::stripSpacesBetweenTags(const QString &input)
 {
+  auto stripped = input;
 
-}
-
-void SpacelessNode::setList( NodeList nodeList )
-{
-  m_nodeList = nodeList;
-}
-
-QString SpacelessNode::stripSpacesBetweenTags( const QString& input )
-{
-  QString stripped = input;
-
-  static const QRegExp re( QStringLiteral( ">\\s+<" ) );
-  stripped.replace( re, QStringLiteral( "><" ) );
+  static const QRegularExpression re(QStringLiteral(">\\s+<"));
+  stripped.replace(re, QStringLiteral("><"));
   return stripped;
 }
 
-
-void SpacelessNode::render( OutputStream *stream, Context *c ) const
+void SpacelessNode::render(OutputStream *stream, Context *c) const
 {
   QString output;
-  QTextStream textStream( &output );
-  QSharedPointer<OutputStream> temp = stream->clone( &textStream );
-  m_nodeList.render( temp.data(), c );
-  ( *stream ) << markSafe( stripSpacesBetweenTags( output.trimmed() ) );
+  QTextStream textStream(&output);
+  auto temp = stream->clone(&textStream);
+  m_nodeList.render(temp.data(), c);
+  (*stream) << markSafe(stripSpacesBetweenTags(output.trimmed()));
 }
