@@ -24,12 +24,18 @@
 #include "grantlee_tags_p.h"
 #include "parser.h"
 
-TemplateTagNodeFactory::TemplateTagNodeFactory() {}
+TemplateTagNodeFactory::TemplateTagNodeFactory() = default;
 
 Node *TemplateTagNodeFactory::getNode(const QString &tagContent,
                                       Parser *p) const
 {
-  auto expr = tagContent.split(QLatin1Char(' '), QString::SkipEmptyParts);
+  auto expr = tagContent.split(QLatin1Char(' '),
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+                               QString::SkipEmptyParts
+#else
+                               Qt::SkipEmptyParts
+#endif
+  );
   expr.takeAt(0);
   if (expr.isEmpty()) {
     throw Grantlee::Exception(
