@@ -19,7 +19,3 @@
 */
 
 #include "i18ntags.h"
-
-#include "grantlee_export_plugin_p.h"
-
-GRANTLEE_EXPORT_PLUGIN( grantlee_i18ntags_library, I18nTagLibrary )
