@@ -26,29 +26,24 @@
 
 using namespace Grantlee;
 
-AbstractLocalizer::AbstractLocalizer()
+AbstractLocalizer::AbstractLocalizer() = default;
+
+AbstractLocalizer::~AbstractLocalizer() = default;
+
+QString AbstractLocalizer::localize(const QVariant &variant) const
 {
-
-}
-
-AbstractLocalizer::~AbstractLocalizer()
-{
-
-}
-
-QString AbstractLocalizer::localize( const QVariant& variant ) const
-{
-  if ( variant.type() == QVariant::Date )
-    return localizeDate( variant.toDate() );
-  if ( variant.type() == QVariant::Time )
-    return localizeTime( variant.toTime() );
-  if ( variant.type() == QVariant::DateTime )
-    return localizeDateTime( variant.toDateTime() );
-  else if ( isSafeString( variant ) )
-    return localizeString( getSafeString( variant ).get() );
-  else if ( variant.type() == QVariant::Double || variant.userType() == QMetaType::Float )
-    return localizeNumber( variant.toReal() );
-  else if ( variant.canConvert( QVariant::Int ) )
-    return localizeNumber( variant.toInt() );
-  return QString();
+  if (variant.userType() == qMetaTypeId<QDate>())
+    return localizeDate(variant.value<QDate>());
+  if (variant.userType() == qMetaTypeId<QTime>())
+    return localizeTime(variant.value<QTime>());
+  if (variant.userType() == qMetaTypeId<QDateTime>())
+    return localizeDateTime(variant.value<QDateTime>());
+  if (isSafeString(variant))
+    return localizeString(getSafeString(variant).get());
+  if (variant.userType() == qMetaTypeId<double>()
+      || variant.userType() == qMetaTypeId<float>())
+    return localizeNumber(variant.value<double>());
+  if (variant.canConvert<int>())
+    return localizeNumber(variant.value<int>());
+  return {};
 }
