@@ -101,11 +101,10 @@ QVariant Context::lookup(const QString &str) const
   Q_D(const Context);
 
   // return a variant from the stack.
-  QListIterator<QVariantHash> i(d->m_variantHashStack);
-  while (i.hasNext()) {
-    const auto h = i.next();
-    if (h.contains(str)) {
-      auto var = h.value(str);
+  for (const auto &h : d->m_variantHashStack) {
+    auto it = h.constFind(str);
+    if (it != h.constEnd()) {
+      auto var = it.value();
       // If the user passed a string into the context, turn it into a
       // Grantlee::SafeString.
       if (var.userType() == qMetaTypeId<QString>()) {
@@ -116,7 +115,7 @@ QVariant Context::lookup(const QString &str) const
     }
   }
 
-  return QVariant();
+  return {};
 }
 
 void Context::push()
