@@ -37,17 +37,24 @@ namespace Grantlee
 /// @headerfile filter.h grantlee/filter.h
 
 /**
-  @brief Base class for all filters
+  @brief Base class for all filters.
 
-  The Filter class can be implemented in plugin libraries to make additional functionality available to templates.
+  The **%Filter** class can be implemented in plugin libraries to make
+  additional functionality available to templates.
 
-  Developers are required only to implement the doFilter method and integrate the filter as part of a custom plugin, but will never create or access filters directly in application code.
+  Developers are required only to implement the @ref doFilter method and
+  integrate the filter as part of a custom plugin, but will never create or
+  access filters directly in application code.
 
-  The FilterExpression class is the access interface to a chain of Filter objects.
+  The FilterExpression class is the access interface to a chain of **%Filter**
+  objects.
 
-  The escape and conditionalEscape methods are available for escaping data where needed.
+  The @ref escape and @ref conditionalEscape methods are available for escaping
+  data where needed.
 
   @see @ref filters
+
+  @author Stephen Kelly <steveire@gmail.com>
 */
 class GRANTLEE_TEMPLATES_EXPORT Filter
 {
@@ -59,36 +66,41 @@ public:
 
 #ifndef Q_QDOC
   /**
-    FilterExpression makes it possible to access stream methods like escape while resolving.
+    FilterExpression makes it possible to access stream methods like escape
+    while resolving.
   */
-  void setStream( OutputStream *stream );
+  void setStream(OutputStream *stream);
 #endif
 
   /**
-    Escapes and returns @p input. The OutputStream::escape method is used to escape @p input.
+    Escapes and returns @p input. The OutputStream::escape method is used to
+    escape @p input.
   */
-  SafeString escape( const QString &input ) const;
+  SafeString escape(const QString &input) const;
 
   /**
-    Escapes and returns @p input. The OutputStream::escape method is used to escape @p input.
+    Escapes and returns @p input. The OutputStream::escape method is used to
+    escape @p input.
   */
-  SafeString escape( const SafeString &input ) const;
+  SafeString escape(const SafeString &input) const;
 
   /**
-    Escapes @p input if not already safe from further escaping and returns it. The OutputStream::escape method is used to escape @p input.
+    Escapes @p input if not already safe from further escaping and returns it.
+    The OutputStream::escape method is used to escape @p input.
   */
-  SafeString conditionalEscape( const SafeString &input ) const;
+  SafeString conditionalEscape(const SafeString &input) const;
 
   /**
     Reimplement to filter @p input given @p argument.
-    @p autoescape determines whether the autoescape feature is currently on or off. Most filters will not use this.
+
+    @p autoescape determines whether the autoescape feature is currently on or
+    off. Most filters will not use this.
 
     @see @ref autoescaping
   */
-  virtual QVariant doFilter( const QVariant &input,
-                             const QVariant &argument = QVariant(),
-                             bool autoescape = false
-                           ) const = 0;
+  virtual QVariant doFilter(const QVariant &input,
+                            const QVariant &argument = {},
+                            bool autoescape = {}) const = 0;
 
   /**
     Reimplement to return whether this filter is safe.
@@ -100,7 +112,6 @@ private:
   OutputStream *m_stream;
 #endif
 };
-
 }
 
 #endif
