@@ -24,30 +24,49 @@
 #include "node.h"
 #include "taglibraryinterface.h"
 
-// #include <QtScript/QScriptEngine>
+#include <QtQml/QJSValue>
 
-// #include <QtScript/QSharedPointer>
-// typedef QSharedPointer<QScriptEngine> ScriptEnginePointer;
-
-class QScriptEngine;
+class QJSEngine;
 
 namespace Grantlee
 {
 class Engine;
 class Parser;
 
+class ScriptableHelperFunctions : public QObject
+{
+  Q_OBJECT
+  QJSEngine *m_scriptEngine;
+
+public:
+  ScriptableHelperFunctions(QJSEngine *scriptEngine)
+      : m_scriptEngine(scriptEngine)
+  {
+  }
+
+  Q_INVOKABLE QJSValue markSafeFunction(QJSValue inputValue);
+  Q_INVOKABLE QJSValue ScriptableFilterExpressionConstructor(QString name,
+                                                             QObject *parserObj
+                                                             = {});
+  Q_INVOKABLE QJSValue ScriptableNodeConstructor(QJSValue callContext);
+  Q_INVOKABLE QJSValue ScriptableVariableConstructor(QString name);
+  Q_INVOKABLE QJSValue ScriptableTemplateConstructor(QString content,
+                                                     QString name,
+                                                     QObject *parent);
+};
+
 class ScriptableTagLibrary : public QObject, public TagLibraryInterface
 {
   Q_OBJECT
   Q_INTERFACES(Grantlee::TagLibraryInterface)
   Q_PLUGIN_METADATA(IID "org.grantlee.TagLibraryInterface")
 public:
-  ScriptableTagLibrary(QObject *parent = 0);
+  ScriptableTagLibrary(QObject *parent = {});
 
   QHash<QString, AbstractNodeFactory *> nodeFactories(const QString &name
-                                                      = QString()) override;
+                                                      = {}) override;
 
-  QHash<QString, Filter *> filters(const QString &name = QString()) override;
+  QHash<QString, Filter *> filters(const QString &name = {}) override;
 
 public Q_SLOTS:
   void addFactory(const QString &factoryName, const QString &tagname);
@@ -59,8 +78,8 @@ protected:
   QHash<QString, Filter *> getFilters();
 
 private:
-  //   ScriptEnginePointer m_scriptEngine;
-  QScriptEngine *m_scriptEngine;
+  QJSEngine *m_scriptEngine;
+  QJSValue m_functions;
   QHash<QString, AbstractNodeFactory *> m_nodeFactories;
   QHash<QString, QString> m_factoryNames;
   QStringList m_filterNames;
